@@ -26,11 +26,11 @@ Pg::Explain::StringAnonymizer - Class to anonymize sets of strings
 
 =head1 VERSION
 
-Version 1.00
+Version 1.01
 
 =cut
 
-our $VERSION = '1.00';
+our $VERSION = '1.01';
 
 =head1 SYNOPSIS
 
@@ -126,6 +126,9 @@ sub finalize {
 
     $self->_stringify();
 
+    my @keys_sorted = sort { length( $b ) <=> length( $a ) } keys %{ $self->{ 'strings' } };
+    $self->{ 'keys_re' } = join '|', map { qr{\Q$_\E} } @keys_sorted;
+
     return;
 }
 
@@ -144,6 +147,20 @@ sub anonymized {
     return $self->{ 'strings' }->{ $input };
 }
 
+=head2 anonymize_text
+
+Anonymize given text using loaded dictionary of substiturions.
+
+=cut
+
+sub anonymize_text {
+    my $self = shift;
+    my $text = shift;
+    my $re   = $self->{ 'keys_re' };
+    $text =~ s{(?:\b|\s)($re)(?:\b|\s)}{ $self->{'strings'}->{$1} }mge;
+    return $text;
+}
+
 =head2 anonymization_dictionary
 
 Returns hash reference containing all input strings and their anonymized versions, like:
